"use server"

import { getServerSession } from "next-auth";
import { Session } from "next-auth";
import { getDivisionSetting, getJackpotSetting } from "@/app/lib/setting/action";
import { JackpotSettingInterface, divisionSettingInterface } from "./types/setting";
import { AuthConfig } from "@/auth";
import { Box, Flex } from "@chakra-ui/react";
import CoinRequest from "./components/coin-request";
import CoinGeneration from "./components/coin-generation";
import JackpotSetting from "./components/JackpotSetting";
import DivisionSetting from "./components/DivisionSetting";

export default async function SettingPage() {
  const session: Session = await getServerSession(AuthConfig);
  const jackpotSetting = await getJackpotSetting();
  const divisionSetting = await getDivisionSetting();


  const jackpotSettingPayload: JackpotSettingInterface = {
    coins: jackpotSetting?.data?.coins ?? 0,
    jackpot_coins_share: divisionSetting?.data[0]?.jackpot_coins_share ?? 0,
    requiredStreak: jackpotSetting?.data?.requiredStreak ?? 0,
  };

  const divisionSettingPayload: divisionSettingInterface = {
    club_share: divisionSetting?.data[0]?.club_share ?? 0,
  };

  const settingId = divisionSetting.data[0]._id ?? null;

  return (
    <Flex flexDir="column" gap="4">
      <CoinRequest availableCoins={session?.user?.coins ?? 0}></CoinRequest>
      <CoinGeneration availableCoins={session?.user?.coins ?? 0}></CoinGeneration>
      <JackpotSetting settingId={settingId} jackpotSetting={jackpotSettingPayload}></JackpotSetting>
      <DivisionSetting settingId={settingId} {...divisionSettingPayload}></DivisionSetting>
    </Flex>
  );
}
